pig_transport/hackney
Hackney adapter for the shared transport.
Values
pub fn ensure_started() -> Nil
pub fn stream(
request: pig_transport.Request,
source: process.Subject(pig_transport.SourceEvent),
) -> Nil
Run the Hackney streaming source for the transport relay.
pub fn sync_request(
method: String,
url: String,
headers: List(#(String, String)),
body: String,
timeout_ms: Int,
) -> pig_transport.Response
Make a blocking Hackney request and return its complete response.